@@ -12,17 +12,15 @@ class DictionaryParameters:
     def __str__(self):
         return "(" + str(len(self.entries)) + ")"
 
-    def Initialize(self, T1s, T2s, B1s=[]):
-        self.entries = np.empty(len(T1s), dtype=DictionaryEntry)
+    def Initialize(self, T1s, T2s, B1s=[1]):
+        self.entries = np.empty(len(T1s)*len(B1s), dtype=DictionaryEntry)
         if (len(T1s)!=len(T2s)):
             print("Import Failed: T1/T2 files must have identical number of entries")
             return 
-        for index in range(len(T1s)):
-            if(B1s != []):
-                for b1Index in range(len(B1s)):
-                    self.entries[index] = (T1s[index], T2s[index], B1s[b1Index])
-            else:
-                self.entries[index] = (T1s[index], T2s[index], None)
+        for b1Index in range(len(B1s)):
+            for t1Index in range(len(T1s)):
+                index = b1Index*len(T1s) + t1Index
+                self.entries[index] = (T1s[t1Index], T2s[t1Index], B1s[b1Index])
         print("Dictionary Parameter set '"+ self.name + "' initialized with " + str(len(self.entries)) + " entries")
     
     def Export(self, filename, force=False):
@@ -63,6 +61,15 @@ class DictionaryParameters:
     def Plot(self):
         plt.plot(self.entries['T1'], self.entries['T2'])
 
+    def GetNearestEntry(self, T1, T2, B1=1):
+        T1diff = np.absolute(self.entries['T1']-T1)
+        T2diff = np.absolute(self.entries['T2']-T2)
+        B1diff = np.absolute(self.entries['B1']-B1)
+        diffs = np.squeeze(np.dstack([T1diff,T2diff,B1diff]))
+        normedDiffs = np.linalg.norm(diffs,axis=1)
+        index = np.argmin(normedDiffs)
+        return (index, self.entries[index])
+
     @staticmethod
     def GetAvailableDictionaryParameters(filename):
         if ".mrf" in filename:
