@@ -123,12 +123,17 @@ class Simulation:
 
         phaseValues = np.linspace(self.phaseRange[0], self.phaseRange[1], self.numSpins)
         dictEntriesPerBatch = int(len(self.dictionaryParameters.entries)/numBatches)
-        print("Simulating " + str(numBatches) + " batch(s) of " + str(dictEntriesPerBatch) + " dictionary entries")
+        print("Simulating " + str(numBatches) + " batch(s) of ~" + str(dictEntriesPerBatch) + " dictionary entries")
         Mxy = np.zeros((self.numTimepoints, len(self.dictionaryParameters.entries)), np.complex128)
         for i in range(numBatches):
             print("Starting Batch: " + str(i))
             firstDictEntry = i*dictEntriesPerBatch
-            lastDictEntry = firstDictEntry+dictEntriesPerBatch
+            if i == (numBatches-1):
+                lastDictEntry = len(self.dictionaryParameters.entries)
+            else:
+                lastDictEntry = firstDictEntry+dictEntriesPerBatch
+            print(firstDictEntry)
+            print(lastDictEntry)
             T1s.clear();T2s.clear();B1s.clear()
             for dictionaryEntry in self.dictionaryParameters.entries[firstDictEntry:lastDictEntry]:
                 T1s.append(dictionaryEntry['T1'])
